@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -487,7 +487,7 @@ public:
    */
   void SyncToDisk();
 
-  /** Returns whether a capability is avalaible.
+  /** Returns whether a capability is available.
    * \param[in] capabilityName  name of the capability to check.
    * \throw None
    * \sa \c GDALDataset::TestCapability()
@@ -567,16 +567,6 @@ private:
 }
 } // end namespace otb::ogr
 
-#if 0
-// Either this, or inheriting from noncopyable is required for DataSource to be
-// compatible with BOOST_FOREACH
-namespace boost { namespace foreach {
-  template<typename T> struct is_noncopyable; // forward declaration
-  template <>
-  struct is_noncopyable<otb::ogr::DataSource> : mpl::true_ {};
-}}
-#endif
-
 #ifndef OTB_MANUAL_INSTANTIATION
 #include "otbOGRDataSourceWrapper.hxx"
 #endif
