@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -74,7 +74,7 @@ CoordinateTransformation::CoordinateTransformation(const SpatialReference& sourc
   if (!tmpTransform)
   {
     std::ostringstream oss;
-    oss << "(InvalidCoordinateTransfromationException) "
+    oss << "(InvalidCoordinateTransformationException) "
         << "Source: " << source << ", target: " << target;
     throw std::runtime_error(oss.str());
   }
@@ -94,7 +94,7 @@ CoordinateTransformation::CoordinateTransformation(const CoordinateTransformatio
   if (!newTransform)
   {
     std::ostringstream oss;
-    oss << "(InvalidCoordinateTransfromationException) "
+    oss << "(InvalidCoordinateTransformationException) "
         << "Source: " << other.GetSourceSpatialReference() << ", target: " << other.GetTargetSpatialReference();
     throw std::runtime_error(oss.str());
   }
@@ -102,14 +102,14 @@ CoordinateTransformation::CoordinateTransformation(const CoordinateTransformatio
   m_Transform = std::move(newTransform);
 }
 
-// Asignment operator
+// Assignment operator
 CoordinateTransformation& CoordinateTransformation::operator=(const CoordinateTransformation& other) noexcept
 {
   // Mimic a clone operator
   CoordinateTransformationPtr newTransform(
       OGRCreateCoordinateTransformation(other.GetSourceSpatialReference().m_SR.get(), other.GetTargetSpatialReference().m_SR.get()));
 
-  // Only update transfrom if newTransform is valid
+  // Only update transform if newTransform is valid
   if (newTransform)
     m_Transform = std::move(newTransform);
 
@@ -126,7 +126,7 @@ SpatialReference CoordinateTransformation::GetTargetSpatialReference() const
   return SpatialReference(m_Transform->GetTargetCS());
 }
 
-// 3D Transfrom of points
+// 3D Transform of points
 std::tuple<double, double, double> CoordinateTransformation::Transform(const std::tuple<double, double, double>& in) const
 {
   double outX, outY, outZ;
@@ -145,7 +145,7 @@ std::tuple<double, double, double> CoordinateTransformation::Transform(const std
   return std::make_tuple(outX, outY, outZ);
 }
 
-// 2D Transfrom of points
+// 2D Transform of points
 std::tuple<double, double> CoordinateTransformation::Transform(const std::tuple<double, double>& in) const
 {
   double outX, outY;
