@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -133,11 +133,13 @@ private:
     AddParameter(ParameterType_InputImage, "ref.raster.in", "Input reference image");
     SetParameterDescription("ref.raster.in", "Input image containing the ground truth labels");
 
-    AddParameter(ParameterType_InputFilename, "ref.vector.in", "Input reference vector data");
+    AddParameter(ParameterType_InputVectorData, "ref.vector.in", "Input reference vector data");
     SetParameterDescription("ref.vector.in", "Input vector data of the ground truth");
 
-    AddParameter(ParameterType_ListView, "ref.vector.field", "Field name");
+    AddParameter(ParameterType_Field, "ref.vector.field", "Field name");
     SetParameterDescription("ref.vector.field", "Field name containing the label values");
+    SetVectorData("ref.vector.field", "ref.vector.in");
+    SetTypeFilter("ref.vector.field", { OFTString, OFTInteger, OFTInteger64 });
     SetListViewSingleSelectionMode("ref.vector.field", true);
 
     AddParameter(ParameterType_Int, "ref.raster.nodata", "Value for nodata pixels in the reference raster");
@@ -186,6 +188,7 @@ private:
 
       ClearChoices("ref.vector.field");
 
+      FieldParameter::TypeFilterType typeFilter = GetTypeFilter("ref.vector.field");
       for (int iField = 0; iField < feature.ogr().GetFieldCount(); iField++)
       {
         std::string key, item = feature.ogr().GetFieldDefnRef(iField)->GetNameRef();
@@ -195,7 +198,7 @@ private:
 
         OGRFieldType fieldType = feature.ogr().GetFieldDefnRef(iField)->GetType();
 
-        if (fieldType == OFTString || fieldType == OFTInteger || fieldType == OFTInteger64)
+        if (typeFilter.empty() || std::find(typeFilter.begin(), typeFilter.end(), fieldType) != std::end(typeFilter))
         {
           std::string tmpKey = "ref.vector.field." + key.substr(0, end - key.begin());
           AddChoice(tmpKey, item);
