@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -63,8 +63,9 @@ private:
     AddParameter(ParameterType_OutputFilename, "outstats", "Output XML file");
     SetParameterDescription("outstats", "XML file containing mean and variance of each feature.");
 
-    AddParameter(ParameterType_ListView, "feat", "Feature");
+    AddParameter(ParameterType_Field, "feat", "Feature");
     SetParameterDescription("feat", "List of features to consider for statistics.");
+    SetVectorData("feat", "inshp");
 
     // Doc example parameter settings
     SetDocExampleParameterValue("inshp", "vectorData.shp");
