@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -75,9 +75,9 @@ private:
     AddParameter(ParameterType_OutputFilename, "insvm", "Input model filename");
     SetParameterDescription("insvm", "Input model filename.");
 
-
-    AddParameter(ParameterType_ListView, "feat", "Features");
+    AddParameter(ParameterType_Field, "feat", "Features");
     SetParameterDescription("feat", "Features to be calculated");
+    SetVectorData("feat","inshp");
 
     AddParameter(ParameterType_String, "cfield", "Field containing the predicted class");
     SetParameterDescription("cfield", "Field containing the predicted class");
