@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -92,15 +92,17 @@ private:
     SetParameterDescription("mask", "Validity mask (only pixels corresponding to a mask value greater than 0 will be used for statistics)");
     MandatoryOff("mask");
 
-    AddParameter(ParameterType_InputFilename, "vec", "Input vectors");
+    AddParameter(ParameterType_InputVectorData, "vec", "Input vectors");
     SetParameterDescription("vec", "Input geometries to analyze");
 
     AddParameter(ParameterType_OutputFilename, "out", "Output XML statistics file");
     SetParameterDescription("out", "Output file to store statistics (XML format)");
 
-    AddParameter(ParameterType_ListView, "field", "Field Name");
+    AddParameter(ParameterType_Field, "field", "Field Name");
     SetParameterDescription("field", "Name of the field carrying the class name in the input vectors.");
     SetListViewSingleSelectionMode("field", true);
+    SetVectorData("field", "vec");
+    SetTypeFilter("field", { OFTString, OFTInteger, OFTInteger64 });
 
     AddParameter(ParameterType_Int, "layer", "Layer Index");
     SetParameterDescription("layer", "Layer index to read in the input vector file.");
@@ -131,6 +133,7 @@ private:
 
       ClearChoices("field");
 
+      FieldParameter::TypeFilterType typeFilter = GetTypeFilter("field");
       for (int iField = 0; iField < feature.ogr().GetFieldCount(); iField++)
       {
         std::string key, item = feature.ogr().GetFieldDefnRef(iField)->GetNameRef();
@@ -140,7 +143,7 @@ private:
 
         OGRFieldType fieldType = feature.ogr().GetFieldDefnRef(iField)->GetType();
 
-        if (fieldType == OFTString || fieldType == OFTInteger || fieldType == OFTInteger64)
+        if (typeFilter.empty() || std::find(typeFilter.begin(), typeFilter.end(), fieldType) != std::end(typeFilter))
         {
           std::string tmpKey = "field." + key.substr(0, end - key.begin());
           AddChoice(tmpKey, item);
@@ -183,10 +186,10 @@ private:
     otb::Wrapper::ElevationParametersHandler::SetupDEMHandlerFromElevationParameters(this, "elev");
 
     // Reproject geometries
-    FloatVectorImageType::Pointer              inputImg            = this->GetParameterImage("in");
-    std::string                                imageProjectionRef  = inputImg->GetProjectionRef();
-    FloatVectorImageType::ImageKeywordlistType imageKwl            = inputImg->GetImageKeywordlist();
-    std::string                                vectorProjectionRef = vectors->GetLayer(GetParameterInt("layer")).GetProjectionRef();
+    auto inputImg            = this->GetParameterImage("in");
+    auto imageProjectionRef  = inputImg->GetProjectionRef();
+    const auto & imageMetadata       = inputImg->GetImageMetadata();
+    auto vectorProjectionRef = vectors->GetLayer(GetParameterInt("layer")).GetProjectionRef();
 
     otb::ogr::DataSource::Pointer reprojVector = vectors;
     GeometriesType::Pointer       inputGeomSet;
@@ -196,7 +199,7 @@ private:
     const OGRSpatialReference     vectorOGRSref = OGRSpatialReference(vectorProjectionRef.c_str());
     bool                          doReproj      = true;
     // don't reproject for these cases
-    if (vectorProjectionRef.empty() || (imgOGRSref.IsSame(&vectorOGRSref)) || (imageProjectionRef.empty() && imageKwl.GetSize() == 0))
+    if (vectorProjectionRef.empty() || (imgOGRSref.IsSame(&vectorOGRSref)) || (imageProjectionRef.empty() && !imageMetadata.HasSensorGeometry()))
       doReproj = false;
 
     if (doReproj)
@@ -209,7 +212,7 @@ private:
       geometriesProjFilter->SetInput(inputGeomSet);
       if (imageProjectionRef.empty())
       {
-        geometriesProjFilter->SetOutputKeywordList(inputImg->GetImageKeywordlist()); // nec qd capteur
+        geometriesProjFilter->SetOutputImageMetadata(&imageMetadata);
       }
       geometriesProjFilter->SetOutputProjectionRef(imageProjectionRef);
       geometriesProjFilter->SetOutput(outputGeomSet);
