@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -121,7 +121,7 @@ private:
     SetParameterDescription("mask", "Validity mask (only pixels corresponding to a mask value greater than 0 will be used for statistics)");
     MandatoryOff("mask");
 
-    AddParameter(ParameterType_InputFilename, "vec", "Input vectors");
+    AddParameter(ParameterType_InputVectorData, "vec", "Input vectors");
     SetParameterDescription("vec", "Input geometries to analyse");
 
     AddParameter(ParameterType_OutputFilename, "out", "Output vectors");
@@ -190,9 +190,10 @@ private:
     // Default strategy : smallest
     SetParameterString("strategy", "smallest");
 
-    AddParameter(ParameterType_ListView, "field", "Field Name");
+    AddParameter(ParameterType_Field, "field", "Field Name");
     SetParameterDescription("field", "Name of the field carrying the class name in the input vectors.");
     SetListViewSingleSelectionMode("field", true);
+    SetVectorData("field", "vec");
 
     AddParameter(ParameterType_Int, "layer", "Layer Index");
     SetParameterDescription("layer", "Layer index to read in the input vector file.");
@@ -349,10 +350,10 @@ private:
     otb::ogr::DataSource::Pointer vectors = otb::ogr::DataSource::New(this->GetParameterString("vec"));
 
     // Reproject geometries
-    FloatVectorImageType::Pointer              inputImg            = this->GetParameterImage("in");
-    std::string                                imageProjectionRef  = inputImg->GetProjectionRef();
-    FloatVectorImageType::ImageKeywordlistType imageKwl            = inputImg->GetImageKeywordlist();
-    std::string                                vectorProjectionRef = vectors->GetLayer(GetParameterInt("layer")).GetProjectionRef();
+    auto inputImg            = this->GetParameterImage("in");
+    auto imageProjectionRef  = inputImg->GetProjectionRef();
+    const auto & imageMetadata       = inputImg->GetImageMetadata();
+    auto vectorProjectionRef = vectors->GetLayer(GetParameterInt("layer")).GetProjectionRef();
 
     otb::ogr::DataSource::Pointer reprojVector = vectors;
     GeometriesType::Pointer       inputGeomSet;
@@ -362,7 +363,7 @@ private:
     const OGRSpatialReference     imgOGRSref    = OGRSpatialReference(imageProjectionRef.c_str());
     const OGRSpatialReference     vectorOGRSref = OGRSpatialReference(vectorProjectionRef.c_str());
     // don't reproject for these cases
-    if (vectorProjectionRef.empty() || (imgOGRSref.IsSame(&vectorOGRSref)) || (imageProjectionRef.empty() && imageKwl.GetSize() == 0))
+    if (vectorProjectionRef.empty() || (imgOGRSref.IsSame(&vectorOGRSref)) || (imageProjectionRef.empty() && !imageMetadata.HasSensorGeometry()))
       doReproj = false;
 
     if (doReproj)
@@ -375,7 +376,7 @@ private:
       geometriesProjFilter->SetInput(inputGeomSet);
       if (imageProjectionRef.empty())
       {
-        geometriesProjFilter->SetOutputKeywordList(inputImg->GetImageKeywordlist()); // nec qd capteur
+        geometriesProjFilter->SetOutputImageMetadata(&imageMetadata);
       }
       geometriesProjFilter->SetOutputProjectionRef(imageProjectionRef);
       geometriesProjFilter->SetOutput(outputGeomSet);
