@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -374,18 +374,17 @@ private:
   // Look for default values in the image metadata
   void SetDefaultValue(const FloatVectorImageType* inImage, std::string what)
   {
-    typedef ImageMetadataInterfaceBase  ImageMetadataInterfaceType;
-    ImageMetadataInterfaceType::Pointer metadataInterface = ImageMetadataInterfaceFactory::CreateIMI(inImage->GetMetaDataDictionary());
     if (what == "NODATA")
     {
-      std::vector<double> values;
-      std::vector<bool>   flags;
+      auto imd = inImage->GetImageMetadata();
 
-      bool ret = metadataInterface->GetNoDataFlags(flags, values);
-
-      if (ret && !values.empty() && !flags.empty() && flags[0])
+      if (imd.Has(MDNum::NoData))
       {
-        SetParameterFloat("nodata", static_cast<float>(values[0]));
+        SetParameterFloat("nodata", static_cast<float>(imd[MDNum::NoData]));
+      }
+      else if ((imd.Bands.size() > 0) && imd.Bands[0].Has(MDNum::NoData))
+      {
+        SetParameterFloat("nodata", static_cast<float>(imd.Bands[0][MDNum::NoData]));
       }
       else
       {
@@ -394,7 +393,7 @@ private:
     }
     else if (what == "RGB")
     {
-      std::vector<unsigned int> rgb = metadataInterface->GetDefaultDisplay();
+      std::vector<unsigned int> rgb = inImage->GetImageMetadata().GetDefaultDisplay();
       unsigned int              m   = inImage->GetVectorLength();
       SetParameterInt("mode.lum.red.ch", rgb[0]);
       SetParameterInt("mode.lum.green.ch", rgb[1]);
@@ -568,7 +567,7 @@ private:
     otbAppLogINFO(<< oss.str());
   }
 
-  // Prepare the first half of the pipe that is common to every methode of
+  // Prepare the first half of the pipe that is common to every method of
   // equalization
   void SetUpPipeline(unsigned int channel, const FloatImageType::Pointer input)
   {
