@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -29,6 +29,7 @@
 #include "otbGenericRSTransform.h"
 #include "otbOGRDataSourceWrapper.h"
 #include "ogrsf_frmts.h"
+#include "otbDEMHandler.h"
 
 namespace otb
 {
@@ -164,7 +165,7 @@ private:
         nextpos                        = line.find_first_of("\t", pos);
         lat                            = atof(line.substr(pos, nextpos).c_str());
 
-        z = otb::DEMHandler::Instance()->GetHeightAboveEllipsoid(lon, lat);
+        z = otb::DEMHandler::GetInstance().GetHeightAboveEllipsoid(lon, lat);
 
         otbAppLogDEBUG("Adding tie point x=" << x << ", y=" << y << ", z=" << z << ", lon=" << lon << ", lat=" << lat);
 
