@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -165,7 +165,7 @@ private:
     }
 
     rsTransform->SetOutputProjectionRef(colorPtr->GetProjectionRef());
-    rsTransform->SetOutputKeywordList(colorPtr->GetImageKeywordlist());
+    rsTransform->SetOutputImageMetadata(&(colorPtr->GetImageMetadata()));
     rsTransform->InstantiateTransform();
     toMap->InstantiateTransform();
 
