@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -154,7 +154,7 @@ private:
     rsRegion.SetOrigin(rsOrigin);
     rsRegion.SetSize(rsSize);
     rsRegion.SetRegionProjection(inImage->GetProjectionRef());
-    rsRegion.SetKeywordList(inImage->GetImageKeywordlist());
+    rsRegion.SetImageMetadata(inImage->GetImageMetadata());
 
     // Set the cartographic region to the extract roi filter
     m_VdExtract->SetRegion(rsRegion);
