@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -20,17 +20,17 @@
 
 
 /* Example usage:
-./DEMToRainbowExample Output/DEMToRainbowImageGenerator.png 6.5 45.5 500 500 0.002 -0.002 Input/DEM_srtm
+./DEMToRainbowExample Output/DEMToRainbowImageGenerator.png 6.5 45.5 500 500 0.002 -0.002 Input/DEM/srtm_directory_srtm
 */
 
 
 /* Example usage:
-./DEMToRainbowExample Output/DEMToHotImageGenerator.png 6.5 45.5 500 500 0.002 -0.002 Input/DEM_srtm hot
+./DEMToRainbowExample Output/DEMToHotImageGenerator.png 6.5 45.5 500 500 0.002 -0.002 Input/DEM/srtm_directory hot
 */
 
 
 /* Example usage:
-./DEMToRainbowExample Output/DEMToReliefImageGenerator.png 6.5 45.5 500 500 0.002 -0.002 Input/DEM_srtm relief
+./DEMToRainbowExample Output/DEMToReliefImageGenerator.png 6.5 45.5 500 500 0.002 -0.002 Input/DEM/srtm_directory relief
 */
 
 #include "otbImageFileReader.h"
@@ -70,7 +70,7 @@ int main(int argc, char* argv[])
   using SpacingType = DEMToImageGeneratorType::SpacingType;
   using PointType   = DEMToImageGeneratorType::PointType;
 
-  otb::DEMHandler::Instance()->OpenDEMDirectory(argv[8]);
+  otb::DEMHandler::GetInstance().OpenDEMDirectory(argv[8]);
 
   PointType origin;
   origin[0] = ::atof(argv[2]);
