@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -63,7 +63,7 @@ struct IsNeighborhood<const itk::ConstNeighborhoodIterator<VectorImage<T>>&> : s
  * \struct IsSuitableType
  * \brief Helper struct to check if a type can be used as pixel type.
  *
- * ::value maps to true if type can be used and false otherwhise.
+ * ::value maps to true if type can be used and false otherwise.
  */
 template <class T>
 struct IsSuitableType : std::is_scalar<T>::type
@@ -107,7 +107,7 @@ struct IsSuitableType<itk::RGBAPixel<T>> : IsSuitableType<T>::type
  * T                                                -> PixelType = T
  * const ConstNeighborhoodIterator<Image::T>&       -> PixelType = T
  * const ConstNeighborhoodIterator<VectorImage::T>& -> PixelType = itk::VariableLengthVector<T>
-*/
+ */
 template <class T>
 struct PixelTypeDeduction
 {
@@ -158,13 +158,13 @@ template <typename T>
 using RemoveCVRef = typename std::remove_cv<typename std::remove_reference<T>::type>::type;
 
 /**
-* \struct RetrieveOperator
-*
-* \brief Struct to retrieve the operator type
-*
-* \tparam T the type to retrieve operator() from
-*
-*/
+ * \struct RetrieveOperator
+ *
+ * \brief Struct to retrieve the operator type
+ *
+ * \tparam T the type to retrieve operator() from
+ *
+ */
 template <typename T>
 struct RetrieveOperator
 {
@@ -173,17 +173,17 @@ struct RetrieveOperator
 };
 
 /**
-* \struct FunctorFilterSuperclassHelper
-* \brief Struct allowing to derive the superclass prototype for the
-*        FunctorImageFilter class
-*
-* Provides the following:
-* - OutputImageType : type of the output image
-* - FilterType : correct instantiation of VariadicInputsImageFilter from
-* - the operator() prototype
-* - InputHasNeighborhood a tuple of N false_type or true_type to denote
-* - if Ith arg of operator() expects a neighborhood.
-*/
+ * \struct FunctorFilterSuperclassHelper
+ * \brief Struct allowing to derive the superclass prototype for the
+ *        FunctorImageFilter class
+ *
+ * Provides the following:
+ * - OutputImageType : type of the output image
+ * - FilterType : correct instantiation of VariadicInputsImageFilter from
+ * - the operator() prototype
+ * - InputHasNeighborhood a tuple of N false_type or true_type to denote
+ * - if Ith arg of operator() expects a neighborhood.
+ */
 template <typename T, typename TNameMap>
 struct FunctorFilterSuperclassHelper : public FunctorFilterSuperclassHelper<typename RetrieveOperator<T>::Type, TNameMap>
 {
@@ -316,7 +316,7 @@ auto NewFunctorFilter(Functor f, itk::Size<2> radius = {{0, 0}});
  * \ingroup IntensityImageFilters   Multithreaded Streamed
  *
  * \ingroup OTBFunctor
-*/
+ */
 template <class TFunction, class TNameMap = void>
 class ITK_EXPORT FunctorImageFilter : public FunctorFilterSuperclassHelper<TFunction, TNameMap>::FilterType
 {
@@ -441,7 +441,7 @@ auto NewFunctorFilter(Functor f, itk::Size<2> radius)
 /**
  * \struct NumberOfOutputBandsDecorator
  * \brief This struct allows forwarding the operator of template
- *        parameter, while adding number of ouptut components service.
+ *        parameter, while adding number of output components service.
  *
  * Its purpose is to enable the use of lambda or functor with
  * Outputsize() method with FunctorImageFilter.
@@ -469,7 +469,7 @@ private:
 /**
  * brief This helper method builds a fully functional
  * FunctorImageFilter from a functor instance which does not provide
- * the OutputSize() service, or a lambda, returing a VariableLengthVector
+ * the OutputSize() service, or a lambda, returning a VariableLengthVector
  *
  * \param[in] f the Functor to build the filter from
  * \param[in] numberOfOutputBands The number of output bands that
@@ -487,7 +487,7 @@ private:
  */
 
 template <typename Functor, typename TNameMap = void>
-auto NewFunctorFilter(Functor f, unsigned int numberOfOutputBands, itk::Size<2> radius)
+auto NewFunctorFilter(Functor f, unsigned int numberOfOutputBands, itk::Size<2> radius = {{0, 0}})
 {
   using FunctorType = NumberOfOutputBandsDecorator<Functor>;
   FunctorType decoratedF(f, numberOfOutputBands);
