@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2019 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -73,7 +73,7 @@ public:
   itkNewMacro(Self);
 
   // Import definitions for SetInput and GetInput to avoid shadowing
-  // by SetInput<> and GetIntput<> defined in this method
+  // by SetInput<> and GetInput<> defined in this method
   using Superclass::GetInput;
   using Superclass::SetInput;
 
@@ -145,7 +145,9 @@ private:
   template <class Tuple, size_t... Is>
   void SetInputsImpl(Tuple& t, std::index_sequence<Is...>)
   {
-    std::initializer_list<int>{(this->template SetInput<Is>(std::get<Is>(t)), 0)...};
+    // Will be easier to write in c++17 with fold expressions 
+    // (this->template SetInput<Is>(std::get<Is>(t)),...);
+    (void) std::initializer_list<int>{(this->template SetInput<Is>(std::get<Is>(t)), 0)...};
   }
 
   template <size_t... Is>
