@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -30,7 +30,7 @@
 #include "itkImage.h"
 #endif
 
-#include "otbImageMetadataInterfaceBase.h"
+#include "otbImageCommons.h"
 #include "OTBImageBaseExport.h"
 
 namespace otb
@@ -86,19 +86,19 @@ namespace otb
  */
 
 template <class TPixel, unsigned int VImageDimension = 2>
-class OTBImageBase_EXPORT_TEMPLATE Image : public itk::Image<TPixel, VImageDimension>
+class OTBImageBase_EXPORT_TEMPLATE Image
+  : public itk::Image<TPixel, VImageDimension>
+  , public ImageCommons
 {
 public:
   /** Standard class typedefs. */
-  typedef Image Self;
-  typedef itk::Image<TPixel, VImageDimension> Superclass;
-  typedef itk::SmartPointer<Self>       Pointer;
-  typedef itk::SmartPointer<const Self> ConstPointer;
-  typedef itk::WeakPointer<const Self>  ConstWeakPointer;
+  using Self = Image;
+  using Superclass = itk::Image<TPixel, VImageDimension>;
+  using Pointer = itk::SmartPointer<Self>;
+  using ConstPointer = itk::SmartPointer<const Self>;
+  using ConstWeakPointer = itk::WeakPointer<const Self>;
 
-  typedef ImageMetadataInterfaceBase::VectorType           VectorType;
-  typedef ImageMetadataInterfaceBase::ImageKeywordlistType ImageKeywordlistType;
-  typedef ImageMetadataInterfaceBase::Pointer              ImageMetadataInterfacePointerType;
+  using VectorType = ImageMetadataInterfaceBase::VectorType;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -174,7 +174,7 @@ public:
   //     return AccessorType();
   //   }
 
-  //   /** Return the Pixel Accesor object */
+  //   /** Return the Pixel Accessor object */
   //   const AccessorType GetPixelAccessor( void ) const
   //   {
   //     return AccessorType();
@@ -192,31 +192,18 @@ public:
     return NeighborhoodAccessorFunctorType();
   }
 
-  /** Get the projection coordinate system of the image. */
-  virtual std::string GetProjectionRef(void) const;
-
-  virtual void SetProjectionRef(const std::string& wkt);
-
-
-  /** Get the GCP projection coordinates of the image. */
-  virtual std::string GetGCPProjection(void) const;
-
-  virtual unsigned int GetGCPCount(void) const;
-
-  virtual OTB_GCP& GetGCPs(unsigned int GCPnum);
-  virtual const OTB_GCP& GetGCPs(unsigned int GCPnum) const;
-
-  virtual std::string GetGCPId(unsigned int GCPnum) const;
-  virtual std::string GetGCPInfo(unsigned int GCPnum) const;
-  virtual double GetGCPRow(unsigned int GCPnum) const;
-  virtual double GetGCPCol(unsigned int GCPnum) const;
-  virtual double GetGCPX(unsigned int GCPnum) const;
-  virtual double GetGCPY(unsigned int GCPnum) const;
-  virtual double GetGCPZ(unsigned int GCPnum) const;
 
   /** Get the six coefficients of affine geoTtransform. */
   virtual VectorType GetGeoTransform(void) const;
 
+  /** Get image corners. */
+  // TODO: GenericRSTransform should be instantiated to translate from physical
+  // space to EPSG:4328 ?
+  VectorType GetUpperLeftCorner(void) const;
+  VectorType GetUpperRightCorner(void) const;
+  VectorType GetLowerLeftCorner(void) const;
+  VectorType GetLowerRightCorner(void) const;
+
   /** Get signed spacing */
   SpacingType GetSignedSpacing() const;
 
@@ -232,19 +219,6 @@ public:
   virtual void SetSignedSpacing(SpacingType spacing);
   virtual void SetSignedSpacing(double spacing[VImageDimension]);
 
-  /** Get image corners. */
-  virtual VectorType GetUpperLeftCorner(void) const;
-  virtual VectorType GetUpperRightCorner(void) const;
-  virtual VectorType GetLowerLeftCorner(void) const;
-  virtual VectorType GetLowerRightCorner(void) const;
-
-  /** Get image keyword list */
-  virtual ImageKeywordlistType GetImageKeywordlist(void);
-
-  virtual const ImageKeywordlistType GetImageKeywordlist(void) const;
-
-  virtual void SetImageKeywordList(const ImageKeywordlistType& kwl);
-
   void PrintSelf(std::ostream& os, itk::Indent indent) const override;
 
   /// Copy metadata from a DataObject
@@ -259,14 +233,6 @@ protected:
 private:
   Image(const Self&) = delete;
   void operator=(const Self&) = delete;
-
-  /** Return the ImageMetadataInterfacePointer associated to the data
- *  and creates it on first call
- */
-  ImageMetadataInterfacePointerType GetMetaDataInterface() const;
-
-  // The image metadata accessor object. Don't use it directly. Instead use GetMetaDataInterface()
-  mutable ImageMetadataInterfacePointerType m_ImageMetadataInterface;
 };
 
 } // end namespace otb
@@ -281,7 +247,7 @@ namespace otb
 {
 
 // Prevent implicit instantiation of common types to improve build performance
-// Explicit instanciations are provided in the .cxx
+// Explicit instantiations are provided in the .cxx
 extern template class OTBImageBase_EXPORT_TEMPLATE Image<unsigned int, 2>;
 extern template class OTBImageBase_EXPORT_TEMPLATE Image<int, 2>;
 extern template class OTBImageBase_EXPORT_TEMPLATE Image<unsigned char, 2>;
