@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -318,11 +318,11 @@ int otbImageFunctionAdaptor(int itkNotUsed(argc), char* argv[])
 
   if (error > 1E-3)
   {
-    itkGenericExceptionMacro(<< "Error = " << error << "  > 1E-9     -> TEST FAILLED" << std::endl);
+    itkGenericExceptionMacro(<< "Error = " << error << "  > 1E-9     -> TEST FAILED" << std::endl);
   }
 
   // Testing the use of a user defined InternalImageFunction instead
-  // of the build-in InternalImageFunction
+  // of the built-in InternalImageFunction
   try
   {
     FMDFunctionType::Pointer             myFunction        = FMDFunctionType::New();
