@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -128,9 +128,8 @@ public:
 
 protected:
   BSplineInterpolateImageFunction();
-  ~BSplineInterpolateImageFunction() override
-  {
-  }
+  ~BSplineInterpolateImageFunction() override = default;
+
   void operator=(const Self&) = delete;
   void PrintSelf(std::ostream& os, itk::Indent indent) const override;
 
