@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -51,71 +51,20 @@ public:
   typedef Superclass::MetaDataDictionaryType   MetaDataDictionaryType;
   typedef Superclass::VectorType               VectorType;
   typedef Superclass::VariableLengthVectorType VariableLengthVectorType;
-  typedef Superclass::ImageKeywordlistType     ImageKeywordlistType;
 
   typedef FilterFunctionValues                              FilterFunctionValuesType;
   typedef otb::ObjectList<FilterFunctionValuesType>         InternalWavelengthSpectralBandVectorType;
   typedef InternalWavelengthSpectralBandVectorType::Pointer WavelengthSpectralBandVectorType;
 
-  /** Get the sun elevation from the ossim metadata
-   * \deprecated
-   */
-  double GetSunElevation() const;
-
-  /** Get the sun azimuth from the ossim metadata
-   * \deprecated
-   */
-  double GetSunAzimuth() const;
-
-  /** Get the sat elevation from the ossim metadata
-   * \deprecated
-   */
-  virtual double GetSatElevation() const = 0;
-
-  /** Get the sat azimuth from the ossim metadata
-   * \deprecated
-   */
-  virtual double GetSatAzimuth() const = 0;
-
-  /** Get the radiometric bias from the ossim metadata
-   * \deprecated
-   */
-  virtual VariableLengthVectorType GetPhysicalBias() const = 0;
-
-  /** Get the radiometric gain from the ossim metadata
-   * \deprecated
-   */
-  virtual VariableLengthVectorType GetPhysicalGain() const = 0;
-
-  /** Get the solar irradiance from the ossim metadata
-   * \deprecated
-   */
-  virtual VariableLengthVectorType GetSolarIrradiance() const = 0;
-
-  /** Get the first wavelength for the spectral band definition */
-  virtual VariableLengthVectorType GetFirstWavelengths() const = 0;
-
-  /** Get the last wavelength for the spectral band definition */
-  virtual VariableLengthVectorType GetLastWavelengths() const = 0;
-
-  /** Get the enhanced band names */
-  std::vector<std::string> GetEnhancedBandNames() const override = 0;
-
   /** This method is to handle the permutation of the spectral band by some image provider
    * in most cases, this method won't change the value, but for SPOT data, the bands are set up as
    *  2 1 0 3 in the tiff file, this method which is overloaded for SPOT enables to retrieve the
    *  proper band. */
   virtual unsigned int BandIndexToWavelengthPosition(unsigned int i) const;
 
-  /** Vector that contains the filter function value in 6S format (step of 0.0025 micro m).
-   * There values a computed by 6S. */
-  virtual WavelengthSpectralBandVectorType GetSpectralSensitivity() const = 0;
-
 protected:
-  OpticalImageMetadataInterface();
-  ~OpticalImageMetadataInterface() override
-  {
-  }
+  OpticalImageMetadataInterface() = default;
+  ~OpticalImageMetadataInterface() override = default;
 
   void PrintSelf(std::ostream& os, itk::Indent indent) const override;
 
