@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -51,20 +51,15 @@ public:
 
   typedef Superclass::ImageType                ImageType;
   typedef ImageType::IndexType                 IndexType;
+  typedef std::array<int, 2>                   ArrayIndexType;
   typedef Superclass::MetaDataDictionaryType   MetaDataDictionaryType;
   typedef Superclass::VectorType               VectorType;
   typedef Superclass::VariableLengthVectorType VariableLengthVectorType;
-  typedef Superclass::ImageKeywordlistType     ImageKeywordlistType;
   typedef itk::PointSet<double, 2> PointSetType;
   typedef PointSetType::Pointer   PointSetPointer;
   typedef double                  RealType;
   typedef PointSetType::PointType PointType;
 
-  RealType GetRadiometricCalibrationScale() const override
-  {
-    itkExceptionMacro("GetRadiometricCalibrationScale() not implemented in SarDefaultImageMetadataInterface, no captor type found");
-  }
-
   PointSetPointer GetRadiometricCalibrationAntennaPatternNewGain() const override
   {
     itkExceptionMacro("GetRadiometricCalibrationAntennaPatternNewGain() not implemented in SarDefaultImageMetadataInterface, no captor type found");
@@ -75,9 +70,9 @@ public:
     itkExceptionMacro("GetRadiometricCalibrationAntennaPatternOldGain() not implemented in SarDefaultImageMetadataInterface, no captor type found");
   }
 
-  PointSetPointer GetRadiometricCalibrationIncidenceAngle() const override
+  PointSetPointer GetRadiometricCalibrationIncidenceAngle(const MetadataSupplierInterface&) const override
   {
-    itkExceptionMacro("GetRadiometricCalibrationIncidenceAngle() not implemented in SarDefaultImageMetadataInterface, no captor type found");
+    itkExceptionMacro("GetRadiometricCalibrationIncidenceAngle(const MetadataSupplierInterface&) not implemented in SarDefaultImageMetadataInterface, no captor type found");
   }
 
   PointSetPointer GetRadiometricCalibrationRangeSpreadLoss() const override
@@ -85,148 +80,58 @@ public:
     itkExceptionMacro("GetRadiometricCalibrationRangeSpreadLoss() not implemented in SarDefaultImageMetadataInterface, no captor type found");
   }
 
-  PointSetPointer GetRadiometricCalibrationNoise() const override
+  PointSetPointer GetRadiometricCalibrationNoise(const MetadataSupplierInterface&, const ImageMetadata&, const std::string&) const override
   {
-    itkExceptionMacro("GetRadiometricCalibrationNoise() not implemented in SarDefaultImageMetadataInterface, no captor type found");
+    itkExceptionMacro("GetRadiometricCalibrationNoise(const MetadataSupplierInterface&) not implemented in SarDefaultImageMetadataInterface, no captor type found");
   }
 
-  IndexType GetRadiometricCalibrationAntennaPatternNewGainPolynomialDegree() const override
+  ArrayIndexType GetRadiometricCalibrationAntennaPatternNewGainPolynomialDegree() const override
   {
     itkExceptionMacro(
         "GetRadiometricCalibrationAntennaPatternNewGainPolynomialDegree() not implemented in SarDefaultImageMetadataInterface, no captor type found");
   }
 
-  IndexType GetRadiometricCalibrationAntennaPatternOldGainPolynomialDegree() const override
+  ArrayIndexType GetRadiometricCalibrationAntennaPatternOldGainPolynomialDegree() const override
   {
     itkExceptionMacro(
         "GetRadiometricCalibrationAntennaPatternOldGainPolynomialDegree() not implemented in SarDefaultImageMetadataInterface, no captor type found");
   }
 
-  IndexType GetRadiometricCalibrationIncidenceAnglePolynomialDegree() const override
+  ArrayIndexType GetRadiometricCalibrationIncidenceAnglePolynomialDegree() const override
   {
     itkExceptionMacro("GetRadiometricCalibrationIncidenceAnglePolynomialDegree() not implemented in SarDefaultImageMetadataInterface, no captor type found");
   }
 
-  IndexType GetRadiometricCalibrationRangeSpreadLossPolynomialDegree() const override
+  ArrayIndexType GetRadiometricCalibrationRangeSpreadLossPolynomialDegree() const override
   {
     itkExceptionMacro("GetRadiometricCalibrationRangeSpreadLossPolynomialDegree() not implemented in SarDefaultImageMetadataInterface, no captor type found");
   }
 
-  IndexType GetRadiometricCalibrationNoisePolynomialDegree() const override
+  ArrayIndexType GetRadiometricCalibrationNoisePolynomialDegree() const override
   {
     itkExceptionMacro("GetRadiometricCalibrationNoisePolynomialDegree() not implemented in SarDefaultImageMetadataInterface, no captor type found");
   }
 
-  /** Get the imaging acquisition day from the ossim metadata
-   * \deprecated
-   */
-  int GetDay() const override
-  {
-    itkExceptionMacro("GetDay not implemented in SarDefaultImageMetadataInterface, no captor type found");
-  }
-
-  /** Get the imaging acquisition month from the ossim metadata
-   * \deprecated
-   */
-  int GetMonth() const override
-  {
-    itkExceptionMacro("GetMonth not implemented in SarDefaultImageMetadataInterface, no captor type found");
-  }
-
-  /** Get the imaging acquisition year from the ossim metadata
-   * \deprecated
-   */
-  int GetYear() const override
-  {
-    itkExceptionMacro("GetYear not implemented in SarDefaultImageMetadataInterface, no captor type found");
-  }
-
-  /** Get the imaging acquisition hour from the ossim metadata
-   * \deprecated
-   */
-  int GetHour() const override
-  {
-    itkExceptionMacro("GetHour not implemented in SarDefaultImageMetadataInterface, no captor type found");
-  }
-
-  /** Get the imaging acquisition minute from the ossim metadata
-   * \deprecated
-   */
-  int GetMinute() const override
-  {
-    itkExceptionMacro("GetMinute not implemented in SarDefaultImageMetadataInterface, no captor type found");
-  }
-
-  /** Get the imaging production day from the ossim metadata
-   * \deprecated
-   */
-  int GetProductionDay() const override
-  {
-    itkExceptionMacro("GetProductionDay not implemented in SarDefaultImageMetadataInterface, no captor type found");
-  }
-
-  /** Get the imaging production month from the ossim metadata
-   * \deprecated
-   */
-  int GetProductionMonth() const override
-  {
-    itkExceptionMacro("GetProductionMonth not implemented in SarDefaultImageMetadataInterface, no captor type found");
-  }
-
-  /** Get the imaging production year from the ossim metadata
-   * \deprecated
-   */
-  int GetProductionYear() const override
-  {
-    itkExceptionMacro("GetProductionYear not implemented in SarDefaultImageMetadataInterface, no captor type found");
-  }
-
-  /** Get the PRF */
-  double GetPRF() const override
-  {
-    itkExceptionMacro("GetPRF not implemented in SarDefaultImageMetadataInterface, no captor type found");
-  }
-
-  /** Get the RSF */
-  double GetRSF() const override
-  {
-    itkExceptionMacro("GetRSF not implemented in SarDefaultImageMetadataInterface, no captor type found");
-  }
-
-  /** Get the radar frequency */
-  double GetRadarFrequency() const override
-  {
-    itkExceptionMacro("GetRadarFrequency not implemented in SarDefaultImageMetadataInterface, no captor type found");
-  }
-
   /** Get the center incidence angle */
-  double GetCenterIncidenceAngle() const override
+  double GetCenterIncidenceAngle(const MetadataSupplierInterface&) const override
   {
     itkExceptionMacro("GetCenterIncidenceAngle not implemented in SarDefaultImageMetadataInterface, no captor type found");
   }
 
-  bool CanRead() const override
+  void ParseGdal(ImageMetadata &) override
   {
-    // This class is the default one, it has to be able to call every metadata
-    return false;
+    itkExceptionMacro("ParseGdal not implemented in SarDefaultImageMetadataInterface, no captor type found");
   }
 
-  /** Get the 3 spectral band numbers corresponding to the default display for visualization,
-   *  in the order R, G, B */
-  UIntVectorType GetDefaultDisplay() const override
+  void ParseGeom(ImageMetadata &) override
   {
-    UIntVectorType rgb(3);
-    rgb[0] = 0;
-    rgb[1] = 0;
-    rgb[2] = 0;
-    return rgb;
+    itkExceptionMacro("ParseGeom not implemented in SarDefaultImageMetadataInterface, no captor type found");
   }
 
+
 protected:
-  SarDefaultImageMetadataInterface(){};
-  ~SarDefaultImageMetadataInterface() override
-  {
-  }
+  SarDefaultImageMetadataInterface() = default;
+  ~SarDefaultImageMetadataInterface() override = default;
 
 private:
   SarDefaultImageMetadataInterface(const Self&) = delete;
