@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -137,7 +137,7 @@ int otbHuMomentsImageFunctionScaleInvariant(int itkNotUsed(argc), char* argv[])
 
   if (error > 1E-3)
   {
-    itkGenericExceptionMacro(<< "Error = " << error << "  > 1E-3     -> TEST FAILLED" << std::endl);
+    itkGenericExceptionMacro(<< "Error = " << error << "  > 1E-3     -> TEST FAILED" << std::endl);
   }
 
   return EXIT_SUCCESS;
@@ -235,7 +235,7 @@ int otbHuMomentsImageFunctionRotationInvariant(int itkNotUsed(argc), char* argv[
 
   if (error > 1E-3)
   {
-    itkGenericExceptionMacro(<< "Error = " << error << "  > 1E-3     -> TEST FAILLED" << std::endl);
+    itkGenericExceptionMacro(<< "Error = " << error << "  > 1E-3     -> TEST FAILED" << std::endl);
   }
 
   return EXIT_SUCCESS;
