@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -25,6 +25,7 @@
 #include "itkScalableAffineTransform.h"
 #include "itkImageBase.h"
 #include "OTBProjectionExport.h"
+#include "otbImageMetadata.h"
 
 namespace otb
 {
@@ -33,7 +34,7 @@ namespace otb
  * \brief Compute the affine transform linking P and XS pixel position for Pleiades sensor bundles
  *
  * Pleiades sensor bundle are exactly homotetic, it is therefore
- * possible to corregister the pancrhomatic and multispectral images
+ * possible to corregister the panchromatic and multispectral images
  * with a simple affine transform without using any sensor
  * modelling. This yields a very accurate corregistration and avoid the
  * use of a DSM which may cause registration errors due to height errors.
@@ -67,35 +68,36 @@ public:
 
   /**
    * This function checks if the transform calculation applies to the
-   * given pair of images. Checked items are:
-   * - Both images are successfully undertood by OTB as Pleiades images,
+   * given pair of ImageMetadata. Checked items are:
+   * - Both ImageMetadata are identified as Pleiades images,
    * - Both images processing level is SENSOR",
+   * - The ImageMetadata contains all required metadata
    * - XS and Pan ids (except last 4 letters) are equal.
    * \return True if the calculation applies
    */
-  static bool CanCompute(const itk::ImageBase<2>* panchromaticImage, const itk::ImageBase<2>* xsImage);
+  static bool CanCompute(const ImageMetadata & panchromaticImd, const ImageMetadata & xsImd);
 
   /**
      * This function computes the offset in pan pixels for a pair of
-     * image. Note that the CanCompute() method is first called, and
+     * ImageMetadata. Note that the CanCompute() method is first called, and
      * that an exception will be raised if computation can not be done.
      *
      * \return The computed transform
      */
-  static OffsetType ComputeOffset(const itk::ImageBase<2>* panchromaticImage, const itk::ImageBase<2>* xsImage);
+  static OffsetType ComputeOffset(const ImageMetadata & panchromaticImd, const ImageMetadata & xsImd);
 
 
   /**
-   * This function computes the transform for a pair of image. Note
+   * This function computes the transform for a pair of ImageMetadata. Note
    * that the CanCompute() method is first called, and that an
    * exception will be raised if computation can not be done.
    *
-   * This function reads both images support data and builds a
-   * transform that will exactly coregister the images.
+   * This function reads both ImageMetadata support data and builds a
+   * transform that will exactly coregister the corresponding images.
    *
    * \return The computed transform
    */
-  static TransformType::Pointer Compute(const itk::ImageBase<2>* panchromaticImage, const itk::ImageBase<2>* xsImage);
+  static TransformType::Pointer Compute(const ImageMetadata & panchromaticImd, const ImageMetadata & xsImd);
 
 private:
   PleiadesPToXSAffineTransformCalculator()            = delete;
