@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -65,13 +65,13 @@ int otbGenericRSTransformFromImage(int itkNotUsed(argc), char* argv[])
   TransformType::Pointer wgs2img = TransformType::New();
   wgs2img->SetInputProjectionRef(wgsRef);
   wgs2img->SetOutputProjectionRef(reader->GetOutput()->GetProjectionRef());
-  wgs2img->SetOutputKeywordList(reader->GetOutput()->GetImageKeywordlist());
+  wgs2img->SetOutputImageMetadata(&(reader->GetOutput()->GetImageMetadata()));
   wgs2img->InstantiateTransform();
 
   // Instantiate Image->WGS transform
   TransformType::Pointer img2wgs = TransformType::New();
   img2wgs->SetInputProjectionRef(reader->GetOutput()->GetProjectionRef());
-  img2wgs->SetInputKeywordList(reader->GetOutput()->GetImageKeywordlist());
+  img2wgs->SetInputImageMetadata(&(reader->GetOutput()->GetImageMetadata()));
   img2wgs->SetOutputProjectionRef(wgsRef);
   img2wgs->InstantiateTransform();
 
@@ -117,22 +117,22 @@ int otbGenericRSTransformImageAndMNTToWGS84ConversionChecking(int itkNotUsed(arg
   GeoDistanceType::Pointer   geoDistance   = GeoDistanceType::New();
   GeoDistance3DType::Pointer geoDistance3d = GeoDistance3DType::New();
 
-  otb::DEMHandler::Pointer demHandler = otb::DEMHandler::Instance();
-  demHandler->OpenDEMDirectory(argv[2]);
-  demHandler->OpenGeoidFile(argv[3]);
-  double heightAboveEllipsoid = demHandler->GetHeightAboveEllipsoid(refGeoPt);
+  auto & demHandler = otb::DEMHandler::GetInstance();
+  demHandler.OpenDEMDirectory(argv[2]);
+  demHandler.OpenGeoidFile(argv[3]);
+  double heightAboveEllipsoid = demHandler.GetHeightAboveEllipsoid(refGeoPt);
 
   // Instantiate WGS->Image transform
   TransformType::Pointer wgs2img = TransformType::New();
   wgs2img->SetInputProjectionRef(wgsRef);
   wgs2img->SetOutputProjectionRef(reader->GetOutput()->GetProjectionRef());
-  wgs2img->SetOutputKeywordList(reader->GetOutput()->GetImageKeywordlist());
+  wgs2img->SetOutputImageMetadata(&(reader->GetOutput()->GetImageMetadata()));
   wgs2img->InstantiateTransform();
 
   // Instantiate Image->WGS transform
   TransformType::Pointer img2wgs = TransformType::New();
   img2wgs->SetInputProjectionRef(reader->GetOutput()->GetProjectionRef());
-  img2wgs->SetInputKeywordList(reader->GetOutput()->GetImageKeywordlist());
+  img2wgs->SetInputImageMetadata(&(reader->GetOutput()->GetImageMetadata()));
   img2wgs->SetOutputProjectionRef(wgsRef);
   img2wgs->InstantiateTransform();
 
@@ -141,13 +141,13 @@ int otbGenericRSTransformImageAndMNTToWGS84ConversionChecking(int itkNotUsed(arg
   Transform3DType::Pointer wgs2img3d = Transform3DType::New();
   wgs2img3d->SetInputProjectionRef(wgsRef);
   wgs2img3d->SetOutputProjectionRef(reader->GetOutput()->GetProjectionRef());
-  wgs2img3d->SetOutputKeywordList(reader->GetOutput()->GetImageKeywordlist());
+  wgs2img3d->SetOutputImageMetadata(&(reader->GetOutput()->GetImageMetadata()));
   wgs2img3d->InstantiateTransform();
 
   // Instantiate Image->WGS transform 3D
   Transform3DType::Pointer img2wgs3d = Transform3DType::New();
   img2wgs3d->SetInputProjectionRef(reader->GetOutput()->GetProjectionRef());
-  img2wgs3d->SetInputKeywordList(reader->GetOutput()->GetImageKeywordlist());
+  img2wgs3d->SetInputImageMetadata(&(reader->GetOutput()->GetImageMetadata()));
   img2wgs3d->SetOutputProjectionRef(wgsRef);
   img2wgs3d->InstantiateTransform();
 
