@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -26,68 +26,42 @@
 #include <iterator>
 
 #include "otbVectorImage.h"
-#include "otbImageFileReader.h"
-#include "otbForwardSensorModel.h"
-#include "otbInverseSensorModel.h"
+#include "otbImageMetadata.h"
+#include "otbRPCForwardTransform.h"
+#include "otbRPCInverseTransform.h"
 #include "otbDEMHandler.h"
-#include <otbImageKeywordlist.h>
 #include "itkEuclideanDistanceMetric.h"
 #include "otbGeographicalDistance.h"
 #include "otbGenericRSTransform.h"
+#include "otbImageMetadata.h"
+#include "otbImageMetadataInterfaceFactory.h"
+#include "otbGeomMetadataSupplier.h"
 #include "otbMacro.h"
 
-#if defined(__GNUC__) || defined(__clang__)
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wunused-parameter"
-#pragma GCC diagnostic ignored "-Woverloaded-virtual"
-#include "ossim/projection/ossimProjection.h"
-#include "ossim/projection/ossimSensorModelFactory.h"
-#pragma GCC diagnostic pop
-#else
-#include "ossim/projection/ossimProjection.h"
-#include "ossim/projection/ossimSensorModelFactory.h"
-#endif
-
-#include "ossim/ossimPluginProjectionFactory.h"
-
-
 typedef std::list<itk::Point<double, 2>> pointsContainerType;
 typedef std::list<itk::Point<double, 3>> geo3dPointsContainerType;
 typedef otb::VectorImage<double, 2>      ImageType;
 typedef itk::Statistics::EuclideanDistanceMetric<ImageType::PointType> DistanceType;
 typedef otb::GeographicalDistance<ImageType::PointType>                GeographicalDistanceType;
 
-int produceGCP(char* outputgcpfilename, const otb::ImageKeywordlist& kwlist, bool useForwardSensorModel = true, double z = 16.19688987731934)
+int produceGCP(char* outputgcpfilename, const otb::ImageMetadata& imd, bool useForwardSensorModel = true, double z = 16.19688987731934)
 {
+  (void)useForwardSensorModel;
+  
   itk::Point<double, 2> imagePoint;
   itk::Point<double, 2> geoPoint;
 
   //  otbForwardSensorModel
-  typedef otb::ForwardSensorModel<double> ForwardSensorModelType;
+  typedef otb::RPCForwardTransform<double, 2, 2> ForwardSensorModelType;
   ForwardSensorModelType::Pointer         forwardSensorModel = ForwardSensorModelType::New();
-  forwardSensorModel->SetImageGeometry(kwlist);
+  forwardSensorModel->SetMetadata(imd);
   if (forwardSensorModel->IsValidSensorModel() == false)
   {
-    otbLogMacro(Warning, << "Invalid Model pointer m_Model == NULL!\n The ossim keywordlist is invalid!");
+    otbLogMacro(Warning, << "Invalid Model pointer m_Model == NULL!\n The metadata is invalid!");
     return EXIT_FAILURE;
   }
 
-  otb::DEMHandler::Instance()->SetDefaultHeightAboveEllipsoid(z);
-
-  // ossim classes
-  ossimKeywordlist ossimKwlist;
-  kwlist.convertToOSSIMKeywordlist(ossimKwlist);
-
-  ossimProjection* ossimSensorModel = ossimSensorModelFactory::instance()->createProjection(ossimKwlist);
-  if (ossimSensorModel == nullptr)
-  {
-    ossimSensorModel = ossimplugins::ossimPluginProjectionFactory::instance()->createProjection(ossimKwlist);
-  }
-  if (ossimSensorModel == nullptr) // Model validity
-  {
-    std::cerr << "Invalid sensor model (ossimSensorModel is NULL)" << std::endl;
-    return EXIT_FAILURE;
-  }
+  otb::DEMHandler::GetInstance().SetDefaultHeightAboveEllipsoid(z);
 
   std::ofstream file(outputgcpfilename, std::ios::out | std::ios::trunc);
   if (file)
@@ -97,21 +71,8 @@ int produceGCP(char* outputgcpfilename, const otb::ImageKeywordlist& kwlist, boo
       {
         imagePoint[0] = x;
         imagePoint[1] = y;
-        if (useForwardSensorModel) // otbForwardSensorModel
-        {
-          geoPoint = forwardSensorModel->TransformPoint(imagePoint);
-        }
-        else // ossim classes
-        {
-          ossimDpt ossimPoint(otb::internal::ConvertToOSSIMFrame(imagePoint[0]),  // x
-                              otb::internal::ConvertToOSSIMFrame(imagePoint[1])); // y
-          ossimGpt ossimGPoint;
-          ossimSensorModel->lineSampleHeightToWorld(ossimPoint, z, ossimGPoint);
-          geoPoint[0] = ossimGPoint.lon;
-          geoPoint[1] = ossimGPoint.lat;
-        }
-
-        file << std::setprecision(16) << x << " " << y << " " << geoPoint[0] << " " << geoPoint[1] << " " << z << std::endl;
+	geoPoint = forwardSensorModel->TransformPoint(imagePoint);
+	file << std::setprecision(16) << x << " " << y << " " << geoPoint[0] << " " << geoPoint[1] << " " << z << std::endl;
       }
   }
   else
@@ -125,10 +86,11 @@ int produceGCP(char* outputgcpfilename, const otb::ImageKeywordlist& kwlist, boo
   return EXIT_SUCCESS;
 }
 
-bool provideGCP(char* gcpfilename, pointsContainerType& imgPt, geo3dPointsContainerType& geo3dPt)
+bool provideGCP(char* gcpfilename, pointsContainerType& imgPt, geo3dPointsContainerType& geo3dPt, pointsContainerType& OSSIMPt)
 {
   itk::Point<double, 2> imagePoint;
   itk::Point<double, 3> geo3dPoint;
+  itk::Point<double, 2> OSSIMPoint;
 
   std::ifstream file(gcpfilename, std::ios::in);
   if (file)
@@ -140,10 +102,11 @@ bool provideGCP(char* gcpfilename, pointsContainerType& imgPt, geo3dPointsContai
       {
         std::istringstream iss(line);
 
-        iss >> imagePoint[0] >> imagePoint[1] >> geo3dPoint[0] >> geo3dPoint[1] >> geo3dPoint[2];
+        iss >> imagePoint[0] >> imagePoint[1] >> geo3dPoint[0] >> geo3dPoint[1] >> geo3dPoint[2] >> OSSIMPoint[0] >> OSSIMPoint[1];
 
         imgPt.push_back(imagePoint);
         geo3dPt.push_back(geo3dPoint);
+	OSSIMPt.push_back(OSSIMPoint);
       }
     }
     file.close();
@@ -156,10 +119,10 @@ bool provideGCP(char* gcpfilename, pointsContainerType& imgPt, geo3dPointsContai
 
 int otbSensorModel(int argc, char* argv[])
 {
-  if (argc != 9)
+  if (argc != 7)
   {
     std::cout << argv[0] << " <input geom filename> <input gcp filename> <output gcp filename> "
-              << " <needed keywords> <imgTol> <geoTol> <writeBaseline> <only check needed keywords>" << std::endl;
+              << " <imgTol> <geoTol> <writeBaseline> <only check needed keywords>" << std::endl;
 
     return EXIT_FAILURE;
   }
@@ -167,58 +130,53 @@ int otbSensorModel(int argc, char* argv[])
   char*              geomfilename = argv[1];
   char*              gcpfilename  = argv[2];
   char*              outFilename  = argv[3];
-  std::istringstream iss(argv[4]);
-  double             imgTol        = atof(argv[5]);
-  double             geoTol        = atof(argv[6]);
-  int                writeBaseline = atoi(argv[7]);
-  bool               checkNeededKw = atoi(argv[8]);
+  double             imgTol        = std::stod(argv[4]);
+  double             geoTol        = std::stod(argv[5]);
+  int                writeBaseline = std::stoi(argv[6]);
 
   // -------------------
   // Some instantiations
   // -------------------
-  otb::ImageKeywordlist kwlist = otb::ReadGeometryFromGEOMFile(geomfilename);
+  otb::ImageMetadata imd;
+  otb::GeomMetadataSupplier geomSupplier(geomfilename);
+  for (int loop = 0 ; loop < geomSupplier.GetNbBands() ; ++loop)
+    imd.Bands.emplace_back();
+  otb::ImageMetadataInterfaceFactory::CreateIMI(imd, geomSupplier);
+  geomSupplier.FetchRPC(imd);
 
-  if (!(kwlist.GetSize() > 0))
-  {
-    std::cerr << "ImageKeywordlist is empty." << std::endl;
-    return EXIT_FAILURE;
-  }
 
   if (writeBaseline)
   {
-    return produceGCP(outFilename, kwlist);
+    return produceGCP(outFilename, imd);
   }
 
-  typedef otb::ImageKeywordlist::KeywordlistMap KeywordlistMapType;
-  KeywordlistMapType                            kwmap = kwlist.GetKeywordlist();
-
   //  otbForwardSensorModel
-  typedef otb::ForwardSensorModel<double> ForwardSensorModelType;
+  typedef otb::RPCForwardTransform<double, 2, 2> ForwardSensorModelType;
   ForwardSensorModelType::Pointer         forwardSensorModel = ForwardSensorModelType::New();
   if (!forwardSensorModel)
   {
     std::cerr << "Invalid sensor model (ForwardSensorModelType::Pointer is NULL)" << std::endl;
     return EXIT_FAILURE;
   }
-  forwardSensorModel->SetImageGeometry(kwlist);
+  forwardSensorModel->SetMetadata(imd);
   if (forwardSensorModel->IsValidSensorModel() == false)
   {
-    std::cerr << "Invalid Model pointer m_Model == NULL!\n The ossim keywordlist is invalid!" << std::endl;
+    std::cerr << "Invalid Model pointer m_Model == NULL!\n The metadata is invalid!" << std::endl;
     return EXIT_FAILURE;
   }
 
   // otbInverseSensorModel
-  typedef otb::InverseSensorModel<double> InverseSensorModelType;
+  typedef otb::RPCInverseTransform<double, 2, 2> InverseSensorModelType;
   InverseSensorModelType::Pointer         inverseSensorModel = InverseSensorModelType::New();
   if (!inverseSensorModel)
   {
     std::cerr << "Invalid sensor model (InverseSensorModelType::Pointer is NULL)" << std::endl;
     return EXIT_FAILURE;
   }
-  inverseSensorModel->SetImageGeometry(kwlist);
+  inverseSensorModel->SetMetadata(imd);
   if (inverseSensorModel->IsValidSensorModel() == false)
   {
-    std::cerr << "Invalid Model pointer m_Model == NULL!\n The ossim keywordlist is invalid!" << std::endl;
+    std::cerr << "Invalid Model pointer m_Model == NULL!\n The metadata is invalid!" << std::endl;
     return EXIT_FAILURE;
   }
 
@@ -240,7 +198,7 @@ int otbSensorModel(int argc, char* argv[])
   }
   img2wgs->SetInputProjectionRef("");
   img2wgs->SetOutputProjectionRef(wgsRef);
-  img2wgs->SetInputKeywordList(kwlist);
+  img2wgs->SetInputImageMetadata(&imd);
   img2wgs->InstantiateTransform();
 
 
@@ -253,24 +211,9 @@ int otbSensorModel(int argc, char* argv[])
   }
   wgs2img->SetInputProjectionRef(wgsRef);
   wgs2img->SetOutputProjectionRef("");
-  wgs2img->SetOutputKeywordList(kwlist);
+  wgs2img->SetOutputImageMetadata(&imd);
   wgs2img->InstantiateTransform();
 
-  // ossim classes
-  ossimKeywordlist ossimKwlist;
-  kwlist.convertToOSSIMKeywordlist(ossimKwlist);
-
-  ossimProjection* ossimSensorModel = ossimSensorModelFactory::instance()->createProjection(ossimKwlist);
-  if (ossimSensorModel == nullptr)
-  {
-    ossimSensorModel = ossimplugins::ossimPluginProjectionFactory::instance()->createProjection(ossimKwlist);
-  }
-  if (ossimSensorModel == nullptr) // Model validity
-  {
-    std::cerr << "Invalid sensor model (ossimSensorModel is NULL)" << std::endl;
-    return EXIT_FAILURE;
-  }
-
   itk::Point<double, 2> imagePoint;
   itk::Point<double, 2> geoPoint, geoPointGCP;
   itk::Point<double, 3> geo3dPoint;
@@ -282,7 +225,8 @@ int otbSensorModel(int argc, char* argv[])
 
   pointsContainerType      pointsContainer;
   geo3dPointsContainerType geo3dPointsContainer;
-  bool                     okStatus = provideGCP(gcpfilename, pointsContainer, geo3dPointsContainer);
+  pointsContainerType      ossimContainer;
+  bool                     okStatus = provideGCP(gcpfilename, pointsContainer, geo3dPointsContainer, ossimContainer);
   if (!okStatus)
   {
     std::cerr << "File" << gcpfilename << " couldn't be opened" << std::endl;
@@ -297,57 +241,17 @@ int otbSensorModel(int argc, char* argv[])
   //--------------------------
 
 
-  //-----------
-  // Tests core
-  //-----------
-
-  // #1 keywordlist, only check the needed keywords
-  /*-------------------------------------*/
-  if (checkNeededKw)
-  {
-    // Split the string into many tokens, with whitespaces as separators
-    std::list<std::string> neededKw;
-    copy(std::istream_iterator<std::string>(iss), std::istream_iterator<std::string>(), back_inserter(neededKw));
-
-
-    std::list<std::string> missingKw;
-    for (std::list<std::string>::iterator neededIt = neededKw.begin(); neededIt != neededKw.end(); ++neededIt)
-    {
-      bool foundNeededKw = false;
-      for (KeywordlistMapType::iterator kwlistIt = kwmap.begin(); kwlistIt != kwmap.end(); ++kwlistIt)
-      {
-        std::size_t found = kwlistIt->first.find(*neededIt);
-        if (found != std::string::npos)
-        {
-          foundNeededKw = true;
-        }
-      }
-
-      if (!foundNeededKw)
-        missingKw.push_back(*neededIt);
-    }
-
-    if ((neededKw.size() > 0) && (missingKw.size() > 0))
-    {
-      std::cerr << "Some keywords were not found; missing keywords : " << std::endl;
-      for (std::list<std::string>::iterator itm = missingKw.begin(); itm != missingKw.end(); ++itm)
-        std::cerr << *itm << std::endl;
-      return EXIT_FAILURE;
-    }
-  }
-  /*-------------------------------------*/
-
-
   pointsContainerType::iterator      pointsIt      = pointsContainer.begin();
   geo3dPointsContainerType::iterator geo3dPointsIt = geo3dPointsContainer.begin();
-  // for(; pointsIt!=pointsContainer.end(); ++pointsIt)
-  while ((pointsIt != pointsContainer.end()) && (geo3dPointsIt != geo3dPointsContainer.end()))
+  pointsContainerType::iterator      ossimIt       = ossimContainer.begin();
+  while ((pointsIt != pointsContainer.end()) && (geo3dPointsIt != geo3dPointsContainer.end()) && (ossimIt != ossimContainer.end()))
   {
     imagePoint = *pointsIt;
     geo3dPoint = *geo3dPointsIt;
-
+    geoPointOSSIM = *ossimIt;
+    
     double z = geo3dPoint[2];
-    otb::DEMHandler::Instance()->SetDefaultHeightAboveEllipsoid(z);
+    otb::DEMHandler::GetInstance().SetDefaultHeightAboveEllipsoid(z);
 
     // otbForwardSensorModel and otbInverseSensorModel
     geoPoint           = forwardSensorModel->TransformPoint(imagePoint);
@@ -357,14 +261,6 @@ int otbSensorModel(int argc, char* argv[])
     geoPointGRS           = img2wgs->TransformPoint(imagePoint);
     reversedImagePointGRS = wgs2img->TransformPoint(geoPointGRS);
 
-    // ossim classes
-    ossimDpt ossimPoint(otb::internal::ConvertToOSSIMFrame(imagePoint[0]),  // x
-                        otb::internal::ConvertToOSSIMFrame(imagePoint[1])); // y
-    ossimGpt ossimGPoint;
-    ossimSensorModel->lineSampleHeightToWorld(ossimPoint, z, ossimGPoint);
-    geoPointOSSIM[0] = ossimGPoint.lon;
-    geoPointOSSIM[1] = ossimGPoint.lat;
-
     // Just for debug purpose
     otbLogMacro(Debug, << "------------------------------------------------");
     otbLogMacro(Debug, << geomfilename);
@@ -375,32 +271,8 @@ int otbSensorModel(int argc, char* argv[])
     otbLogMacro(Debug, << std::setprecision(15) << "Image to geo (OSSIM): " << imagePoint << " -> " << geoPointOSSIM);
 
 
-    // 3. Results should be plausible (no NaN and no clearly out of bound results)
+    // 3. Results should be plausible (not clearly out of bound results)
     /*-------------------------------------*/
-    if ((ossim::isnan(geoPoint[0])) || (ossim::isnan(geoPoint[1])))
-    {
-      std::cerr << " Nan results (otbForwardSensorModel otbInverseSensorModel) : image to geo: " << imagePoint << " -> " << geoPoint << "\n";
-      return EXIT_FAILURE;
-    }
-
-    if ((ossim::isnan(geoPointGRS[0])) || (ossim::isnan(geoPointGRS[1])))
-    {
-      std::cerr << "Nan results (otbGenericRSTransform) : image to geo: " << imagePoint << " -> " << geoPointGRS << "\n";
-      return EXIT_FAILURE;
-    }
-
-    if ((ossim::isnan(reversedImagePoint[0])) || (ossim::isnan(reversedImagePoint[1])))
-    {
-      std::cerr << "Nan results (otbForwardSensorModel otbInverseSensorModel) : geo to image: " << geoPoint << " -> " << reversedImagePoint << "\n";
-      return EXIT_FAILURE;
-    }
-
-    if ((ossim::isnan(reversedImagePointGRS[0])) || (ossim::isnan(reversedImagePointGRS[1])))
-    {
-      std::cerr << "Nan results (otbGenericRSTransform) : geo to image: " << geoPointGRS << " -> " << reversedImagePointGRS << "\n";
-      return EXIT_FAILURE;
-    }
-
     if (!((geoPoint[0] >= -180.0) && (geoPoint[0] <= 180.0)) || !((geoPoint[1] >= -90.0) && (geoPoint[1] <= 90.0)))
     {
       std::cerr << "GeoPoint out of bound (otbForwardSensorModel otbInverseSensorModel) : " << geoPoint << "\n";
@@ -483,6 +355,7 @@ int otbSensorModel(int argc, char* argv[])
 
     ++pointsIt;
     ++geo3dPointsIt;
+    ++ossimIt;
   }
   //-----------------
   // Tests core (end)
