@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -23,7 +23,6 @@
 
 #include "otbVectorDataToVectorDataFilter.h"
 #include "otbRemoteSensingRegion.h"
-#include "otbDEMHandler.h"
 #include "itkMacro.h"
 #include "itkPreOrderTreeIterator.h"
 
@@ -94,7 +93,7 @@ public:
   typedef typename VectorDataType::DataTreeType::TreeNodeType              InternalTreeNodeType;
   typedef typename InternalTreeNodeType::ChildrenListType                  ChildrenListType;
 
-  /** Method to Set/Get the Region of intereset*/
+  /** Method to Set/Get the Region of interest*/
   void SetRegion(const RegionType& region)
   {
     m_ROI = region;
@@ -107,9 +106,8 @@ public:
 
 protected:
   VectorDataExtractROI();
-  ~VectorDataExtractROI() override
-  {
-  }
+  ~VectorDataExtractROI() override = default;
+
   void PrintSelf(std::ostream& os, itk::Indent indent) const override;
 
   /** Method to compare the projection embedded in the cartoRegion And the the InputVectorData*/
