@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -77,7 +77,7 @@ public:
   GDALDatasetWrapper::Pointer Open(std::string filename) const;
 
   // Open the new  file for writing and returns a smart dataset pointer
-  GDALDatasetWrapper::Pointer Create(std::string driverShortName, std::string filename, int nXSize, int nYSize, int nBands, GDALDataType eType,
+  GDALDatasetWrapper::Pointer Create(std::string& driverShortName, std::string filename, int nXSize, int nYSize, int nBands, GDALDataType eType,
                                      char** papszOptions) const;
 
 
