@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -33,4 +33,7 @@ void RegisterTests()
   REGISTER_TEST(otbGDALImageIOTestCanRead);
   REGISTER_TEST(otbMultiDatasetReadingInfo);
   REGISTER_TEST(otbOGRVectorDataIOTestCanRead);
+  REGISTER_TEST(otbDEMHandlerTest);
+  REGISTER_TEST(otbGDALRPCTransformerTest);
+  REGISTER_TEST(otbGDALRPCTransformerTest2);
 }
