@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -310,7 +310,7 @@ bool RADImageIO::InternalReadHeaderInformation(const std::string& file_name, std
   {
     if (reportError == true)
     {
-      itkExceptionMacro(<< "RAD : the first line of the header file must be contains 'TYPECODAGE' caracters.");
+      itkExceptionMacro(<< "RAD : the first line of the header file must be contains 'TYPECODAGE' characters.");
     }
     else
     {
@@ -746,7 +746,7 @@ void RADImageIO::WriteImageInformation()
   for (unsigned int channels = 0; channels < m_ChannelsFileName.size(); ++channels)
   {
     m_ChannelsFile[channels].seekp(0, std::ios::beg);
-    // Write Header line and all file (whitout information)
+    // Write Header line and all file (without information)
     for (unsigned int numLigne = 0; numLigne < (m_Dimensions[1]); numLigne++)
     {
       m_ChannelsFile[channels].write(value, numberOfBytesPerLines);
