@@ -28,7 +28,7 @@
 #include "itkImageIOBase.h"
 #include "OTBImageIOExport.h"
 
-#include <boost/shared_ptr.hpp>
+#include <memory>
 
 namespace otb
 {
@@ -117,7 +117,7 @@ public:
 
   /** Connect a new input to the multi-writer. Only the input pointer is
    *  required. If the filename list is empty,
-   *  streaming will occur without writing. It the filename list contains more
+   *  streaming will occur without writing. If the filename list contains more
    *  than one element, then the output will be divided into this number of
    *  granule files. The resolution factor specifies the ratio between the height of this image and the
    *  height of a reference image. The number of lines per strip class parameter will be modified according to this factor, so
@@ -130,7 +130,7 @@ public:
 
 
   /** Add a new ImageFileWriter to the multi-writer. This is an alternative method
-   *  when you already have an instanciated writer.
+   *  when you already have an instantiated writer.
    */
   template <class TWriter>
   void AddInputWriter(typename TWriter::Pointer writer);
@@ -234,7 +234,7 @@ private:
     virtual void WriteImageInformation()                 = 0;
     virtual void Write(const RegionType& streamRegion)   = 0;
     virtual bool                        CanStreamWrite() const = 0;
-    typedef boost::shared_ptr<SinkBase> Pointer;
+    typedef std::shared_ptr<SinkBase> Pointer;
 
 
     virtual itk::ImageRegion<2> GetRegionToWrite() const = 0;
@@ -266,7 +266,7 @@ private:
     void WriteImageInformation() override;
     void Write(const RegionType& streamRegion) override;
     bool                    CanStreamWrite() const override;
-    typedef boost::shared_ptr<Sink> Pointer;
+    typedef std::shared_ptr<Sink> Pointer;
     
     /** Get the region that should be written. By default this is the largest possible region
      * of the input image, but this might be overridden by the box extended filename parameter of 
@@ -282,8 +282,8 @@ private:
   };
 
   /** The list of inputs and their associated parameters, built using AddInput */
-  typedef std::vector<boost::shared_ptr<SinkBase>> SinkListType;
-  SinkListType                                     m_SinkList;
+  typedef std::vector<std::shared_ptr<SinkBase>> SinkListType;
+  SinkListType                                   m_SinkList;
 
   std::vector<RegionType> m_StreamRegionList;
 };
