@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -68,10 +68,10 @@ public:
   void barrier();
 
   /** Log error */
-  void logError(const std::string message);
+  void logError(const std::string& message);
 
   /** Log info */
-  void logInfo(const std::string message);
+  void logInfo(const std::string& message);
 
 protected:
   /** Constructor */
