@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 1999-2011 Insight Software Consortium
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -62,11 +62,11 @@ public:
   {
     m_WeightingValues = cont;
   }
-  void SetUpwardTransmittanceRatio(DoubleContainerType upwardTransmittanceRatio)
+  void SetUpwardTransmittanceRatio(DoubleContainerType& upwardTransmittanceRatio)
   {
     m_UpwardTransmittanceRatio = upwardTransmittanceRatio;
   }
-  void SetDiffuseRatio(DoubleContainerType diffuseRatio)
+  void SetDiffuseRatio(DoubleContainerType& diffuseRatio)
   {
     m_DiffuseRatio = diffuseRatio;
   }
