@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -96,7 +96,7 @@ protected:
   /** Constructor from a ASCII file */
   // AtmosphericEffects( const std::string & filename );
   /** Destructor */
-  ~AtmosphericEffects() override{};
+  ~AtmosphericEffects() override = default;;
   /** PrintSelf method */
   // void PrintSelf(std::ostream& os, itk::Indent indent) const;
 
