@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -94,8 +94,6 @@ public:
   typedef typename PointSetType::PointsContainer    PointsContainer;
   typedef typename PointSetType::PointDataContainer LabelContainer;
 
-  typedef otb::ImageKeywordlist ImageKeywordListType;
-
   typedef std::map<unsigned int, itk::ImageRegionConstIterator<DisparityMapType>> DispMapIteratorList;
 
   typedef std::map<unsigned int, itk::ImageRegionConstIterator<MaskImageType>> MaskIteratorList;
@@ -126,24 +124,24 @@ public:
   const TResidueImage* GetResidueOutput() const;
   TResidueImage*       GetResidueOutput();
 
-  /** Set keywordlist of the reference image */
-  void SetReferenceKeywordList(const ImageKeywordListType kwl)
+  /** Set ImageMetadata of the reference image */
+  void SetReferenceImageMetadata(const ImageMetadata* imd)
   {
-    this->m_ReferenceKeywordList = kwl;
+    this->m_ReferenceImageMetadata = imd;
     this->Modified();
   }
 
-  /** Get keywordlist of the reference image */
-  const ImageKeywordListType& GetReferenceKeywordList() const
+  /** Get ImageMetadata of the reference image */
+  const ImageMetadata* GetReferenceImageMetadata() const
   {
-    return this->m_ReferenceKeywordList;
+    return this->m_ReferenceImageMetadata;
   }
 
-  /** Set keywordlist of the moving image 'index' */
-  void SetMovingKeywordList(unsigned int index, const ImageKeywordListType kwl);
+  /** Set ImageMetadata of the moving image 'index' */
+  void SetMovingImageMetadata(unsigned int index, const ImageMetadata* imd);
 
-  /** Get keywordlist of the moving image 'index' */
-  const ImageKeywordListType& GetMovingKeywordList(unsigned int index) const;
+  /** Get ImageMetadata of the moving image 'index' */
+  const ImageMetadata* GetMovingImageMetadata(unsigned int index) const;
 
 protected:
   /** Constructor */
@@ -158,9 +156,6 @@ protected:
   /** Generate input requested region */
   void GenerateInputRequestedRegion() override;
 
-  /** Before threaded generate data */
-  void BeforeThreadedGenerateData() override;
-
   /** Threaded generate data */
   void ThreadedGenerateData(const RegionType& outputRegionForThread, itk::ThreadIdType threadId) override;
 
@@ -168,17 +163,13 @@ private:
   MultiDisparityMapTo3DFilter(const Self&) = delete;
   void operator=(const Self&) = delete;
 
-  /** Keywordlist of reference sensor image */
-  ImageKeywordListType m_ReferenceKeywordList;
+  /** ImageMetadata of reference sensor image */
+  const ImageMetadata*   m_ReferenceImageMetadata = nullptr;
+  
+  /** ImageMetadata of moving sensor images */
+  std::vector<const ImageMetadata*> m_MovingImageMetadatas;
 
-  /** Keywordlists of moving sensor images */
-  std::vector<ImageKeywordListType> m_MovingKeywordLists;
 
-  /** Reference sensor image transform */
-  RSTransformType::Pointer m_ReferenceToGroundTransform;
-
-  /** Moving sensor image transforms */
-  std::vector<RSTransformType::Pointer> m_MovingToGroundTransform;
 };
 } // end namespace otb
 
