@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -25,7 +25,9 @@
 
 #include "otbImageList.h"
 #include "otbVectorImageToImageListFilter.h"
+#include "otbDEMHandler.h"
 
+#include "otbDEMHandler.h"
 
 const unsigned int Dimension = 2;
 typedef float      PixelType;
@@ -84,7 +86,7 @@ int otbDisparityMapToDEMFilter(int argc, char* argv[])
   filter->SetElevationMax(atof(argv[8]));
   filter->SetDEMGridStep(atof(argv[10]));
 
-  otb::DEMHandler::Instance()->SetDefaultHeightAboveEllipsoid(atof(argv[9]));
+  otb::DEMHandler::GetInstance().SetDefaultHeightAboveEllipsoid(atof(argv[9]));
 
   MaskReaderType::Pointer maskReader;
   if (argc == 12)
