@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -79,12 +79,13 @@ protected:
     se.CreateStructuringElement();
     this->GetFilter()->SetKernel(se);
   }
+
   /** Constructor */
   MorphologicalOpeningProfileFilter(){};
+
   /** Destructor */
-  ~MorphologicalOpeningProfileFilter() override
-  {
-  }
+  ~MorphologicalOpeningProfileFilter() override = default;
+
   /**PrintSelf method */
   void PrintSelf(std::ostream& os, itk::Indent indent) const override
   {
