@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2019 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -168,8 +168,8 @@ public:
   using AcquistionParameterType = TAcquistionParameter;
   using SatRSRType              = TSatRSR;
   using SatRSRPointerType       = typename SatRSRType::Pointer;
-  using ProspectType            = typename otb::ProspectModel;
-  using SailType                = typename otb::SailModel;
+  using ProspectType            = otb::ProspectModel;
+  using SailType                = otb::SailModel;
 
   using PrecisionType                 = double;
   using PairType                      = std::pair<PrecisionType, PrecisionType>;
@@ -344,7 +344,7 @@ protected:
 } // namespace Functor
 
 // \code{TernaryFunctorImageFilterWithNBands} class is defined here.
-// This class inherits form \doxygen{itk}{TernaryFunctorImageFilter} with additional nuber of band parameters.
+// This class inherits form \doxygen{itk}{TernaryFunctorImageFilter} with additional number of band parameters.
 // It's implementation is done to process Label, LAI, and mask image with Simulation functor.
 
 template <class TInputImage1, class TInputImage2, class TInputImage3, class TOutputImage, class TFunctor>
