@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -50,4 +50,4 @@ using VertexArrayObject = Handle< VertexArrayObjectPolicy >;
 } // end namespace otb.
 
 
-#endif // otb_GlVetexArrayObject_h
+#endif // otb_GlVertexArrayObject_h
