@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -138,7 +138,6 @@ GeoInterface
   return INITIALIZER.GetSpacing();
 }
 
-
 std::string
 GeoInterface
 ::GetWkt() const
@@ -146,18 +145,9 @@ GeoInterface
   return std::string();
 }
 
-
 bool
 GeoInterface
-::HasKwl() const
-{
-  return false;
-}
-
-
-bool
-GeoInterface
-::GetKwl( ImageKeywordlist & ) const
+::GetImd( ImageMetadata &) const
 {
   return false;
 }
