@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -96,7 +96,7 @@ public:
 
   //
   // SIGNALS.
-signals:
+Q_SIGNALS:
 
   /*-[ PROTECTED SECTION ]---------------------------------------------------*/
 
@@ -126,7 +126,7 @@ private:
 
   //
   // Slots.
-private slots:
+private Q_SLOTS:
 
   /**
    * \brief Qt auto-connected slot which is called when datasetPathButton menu
