@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  * Copyright (C) 2017 CS Systemes d'Information (CS SI)
  *
  * This file is part of Orfeo Toolbox
@@ -1250,31 +1250,31 @@ void MainWindow::on_action_SaveScreenshot_triggered()
 /*****************************************************************************/
 void MainWindow::on_action_ZoomIn_triggered()
 {
-  emit UserZoomIn();
+  Q_EMIT UserZoomIn();
 }
 
 /*****************************************************************************/
 void MainWindow::on_action_ZoomOut_triggered()
 {
-  emit UserZoomOut();
+  Q_EMIT UserZoomOut();
 }
 
 /*****************************************************************************/
 void MainWindow::on_action_ZoomExtent_triggered()
 {
-  emit UserZoomExtent();
+  Q_EMIT UserZoomExtent();
 }
 
 /*****************************************************************************/
 void MainWindow::on_action_ZoomFull_triggered()
 {
-  emit UserZoomFull();
+  Q_EMIT UserZoomFull();
 }
 
 /*****************************************************************************/
 void MainWindow::on_action_ZoomLayer_triggered()
 {
-  emit UserZoomLayer();
+  Q_EMIT UserZoomLayer();
 }
 
 /*****************************************************************************/
@@ -1307,7 +1307,7 @@ void MainWindow::OnAboutToChangeModel(const AbstractModel*)
   if (stackedLayerModel == NULL)
     return;
 
-  // Disonnect stacked-layer model from main-window when selected
+  // Disconnect stacked-layer model from main-window when selected
   // layer-model is about to change.
   QObject::disconnect(stackedLayerModel, SIGNAL(AboutToChangeSelectedLayerModel(const StackedLayerModel::KeyType&)),
                       // from:
