@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -95,7 +95,7 @@ class VectorImageModel;
  *
  * QCoreApplication is passed as argument of I18nCoreApplication
  * constructor. So, is user application must derive QApplication (to,
- * for example, provide sessio management), the specialized instance
+ * for example, provide session management), the specialized instance
  * can be passed as argument of constructor.
  */
 class OTBMonteverdiCore_EXPORT I18nCoreApplication : public QObject
@@ -327,13 +327,13 @@ public:
   static const char* DATASET_EXT;
 
   /*-[ PUBLIC SLOTS SECTION ]-----------------------------------------------**/
-public slots:
+public Q_SLOTS:
   /**
    * \brief Accessor used to changed model which is managed by the
    * Application.
    *
    * This method emits the AboutToChangeModel() and ModelChanged()
-   * signals respectively, before and after, the model is changed.
+   * Q_SIGNALS respectively, before and after, the model is changed.
    *
    * \param model The newly managed model.
    */
@@ -345,7 +345,7 @@ public slots:
 
   //
   // SIGNALS.
-signals:
+Q_SIGNALS:
   /**
    * \brief Signal emitted when the AbstractModel of the MVC is about
    * to be changed.
@@ -481,7 +481,7 @@ private:
 
   //
   // SLOTS
-private slots:
+private Q_SLOTS:
 };
 
 } // end namespace 'mvd'
