@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -124,11 +124,11 @@ QStringList AbstractImageModel::GetBandNames(bool enhanced) const
 {
   ImageBaseType::ConstPointer output(ToImageBase());
 
-  otb::ImageMetadataInterfaceBase::ConstPointer metaDataInterface(GetMetaDataInterface());
+  const auto & imd = GetImageMetadata();
 
   //
   // Basic band names.
-  StringVector stdBandNames1(metaDataInterface->GetBandName());
+  auto stdBandNames1 = imd.GetBandNames();
 
   // output band name list
   QStringList qBandNames1(QString(""));
@@ -170,7 +170,7 @@ QStringList AbstractImageModel::GetBandNames(bool enhanced) const
     {
       try
       {
-        stdBandNames2 = metaDataInterface->GetEnhancedBandNames();
+        stdBandNames2 = imd.GetEnhancedBandNames();
       }
       catch (std::exception& exc)
       {
@@ -222,7 +222,7 @@ void AbstractImageModel::RefreshHistogram(void* const context)
   HistogramModel::BuildContext* const buildContext =
     static_cast< HistogramModel::BuildContext* const >( context );
 
-  // Force writing histgram file by setting IsBeingStored flag.
+  // Force writing histogram file by setting IsBeingStored flag.
   buildContext->m_IsBeingStored = true;
 #endif
 
