@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -188,9 +188,9 @@ void ApplicationsBrowser::SearchAvailableApplicationsTags()
   }
 
   //
-  // emit a signal with the ApplicationsTagContainer as
+  // Q_EMIT a signal with the ApplicationsTagContainer as
   // parameter
-  emit AvailableApplicationsTagsChanged(outputContainer);
+  Q_EMIT AvailableApplicationsTagsChanged(outputContainer);
 }
 
 /*******************************************************************************/
