@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -87,7 +87,7 @@ private:
 
   void SetupFileSelectionWidget(QWidget*);
 
-private slots:
+private Q_SLOTS:
 
   // slot in charge of emitting a signal to the catalogue mainWindow.
   // when received, the main application need to get the output
