@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -127,13 +127,13 @@ public:
   /*-[ PUBLIC SLOTS SECTION ]------------------------------------------------*/
 
   // public slots
-public slots:
+public Q_SLOTS:
 
   /*-[ SIGNALS SECTION ]-----------------------------------------------------*/
 
   //
   // SIGNALS.
-signals:
+Q_SIGNALS:
 
   /*-[ PROTECTED SECTION ]---------------------------------------------------*/
 
@@ -157,7 +157,7 @@ private:
   //
   // Private methods.
 private:
-  void SetWktAndKwl();
+  void SetWktAndImd();
 
   //
   // ImageViewRenderer methods.
@@ -180,7 +180,7 @@ private:
 
   //
   // SLOTS.
-private slots:
+private Q_SLOTS:
 };
 
 } // end namespace 'mvd'
