@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -110,7 +110,7 @@ public:
 
   //
   // Public SLOTS.
-public slots:
+public Q_SLOTS:
 
   void GrayscaleActivated(bool status);
 
@@ -118,7 +118,7 @@ public slots:
 
   //
   // Signals.
-signals:
+Q_SIGNALS:
   void SettingsChanged();
 
   /*-[ PROTECTED SECTION ]---------------------------------------------------*/
@@ -159,7 +159,7 @@ private:
 
   //
   // Slots.
-private slots:
+private Q_SLOTS:
   void on_effectComboBox_currentIndexChanged(const QString&);
   void on_sizeSpinBox_valueChanged(int);
   void on_valueLineEdit_editingFinished();
