@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2019 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -803,7 +803,7 @@ void ImageViewRenderer::virtual_ClearScene(bool keepViewport)
   //
   // MANTIS-1244: image-view not reset when layer-stack is cleared.
   // {
-  emit ResetViewport();
+  Q_EMIT ResetViewport();
   // }
 }
 
@@ -858,7 +858,7 @@ void ImageViewRenderer::virtual_UpdateScene()
 
           // Should all AbstractLayerModel have a ::GetFilename()
           // method?
-          // -> Not sure: AbstractImageModel coud be derived as a
+          // -> Not sure: AbstractImageModel could be derived as a
           // in-memory image-model.
           VectorImageModel* vectorImageModel = dynamic_cast<VectorImageModel*>(it->second);
 
@@ -932,7 +932,7 @@ void ImageViewRenderer::virtual_RefreshScene()
 
     // m_GlView->GetSettings()->SetUseProjection( false );
 
-    // emit ClearProjectionRequired();
+    // Q_EMIT ClearProjectionRequired();
 
     return;
   }
@@ -951,7 +951,7 @@ void ImageViewRenderer::virtual_RefreshScene()
 
     m_GlView->GetSettings()->SetUseProjection(false);
 
-    emit ClearProjectionRequired();
+    Q_EMIT ClearProjectionRequired();
 
     return;
   }
@@ -996,13 +996,13 @@ void ImageViewRenderer::virtual_RefreshScene()
     {
       virtual_SetProjection();
 
-      emit SetProjectionRequired();
+      Q_EMIT SetProjectionRequired();
     }
     else if (m_ReferencePair.first != referencePair.first)
     {
       virtual_UpdateProjection();
 
-      emit UpdateProjectionRequired();
+      Q_EMIT UpdateProjectionRequired();
     }
   }
 
