@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -91,6 +91,6 @@ void ProjectionBarWidget::ChangeScale()
   }
 
   // Emit scale changed.
-  emit ProjectionScaleChanged(numerator / denominator);
+  Q_EMIT ProjectionScaleChanged(numerator / denominator);
 }
 }
