@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -45,28 +45,18 @@ namespace details
 template <typename TOutputImage, typename TInputImage>
 struct OTBApplicationEngine_EXPORT_TEMPLATE CastImage
 {
-  /** Input clamping */
-  using InputClampImageFilter = ClampImageFilter<TInputImage, DoubleVectorImageType>;
+  using InOutClampImageFilter = ClampImageFilter<TInputImage, TOutputImage>;
 
-  /** Output clamping */
-  using OutputClampImageFilter = ClampImageFilter<DoubleVectorImageType, TOutputImage>;
-
-
-  /** Constructor. */
-  CastImage(TInputImage* in) : icif(InputClampImageFilter::New()), ocif(OutputClampImageFilter::New()), out(ocif->GetOutput())
+  CastImage(TInputImage *in)
+  : ocif(InOutClampImageFilter::New())
+  , out(ocif->GetOutput())
   {
     assert(in);
-
-    icif->SetInput(in);
-
-    ocif->SetInput(icif->GetOutput());
+    ocif->SetInput(in);
   }
 
-  /** Input-image clamp filter. */
-  typename InputClampImageFilter::Pointer icif;
-
   /** Output-image clamp filter. */
-  typename OutputClampImageFilter::Pointer ocif;
+  typename InOutClampImageFilter::Pointer ocif;
 
   /** Output image. */
   TOutputImage* out;
@@ -85,18 +75,16 @@ struct OTBApplicationEngine_EXPORT_TEMPLATE CastImage<TOutputImage, DoubleVector
   /** Output clamping */
   using OutputClampImageFilter = ClampImageFilter<DoubleVectorImageType, TOutputImage>;
 
-
   /** Constructor. */
-  CastImage(DoubleVectorImageType* in) : ocif(OutputClampImageFilter::New()), out(ocif->GetOutput())
+  CastImage(DoubleVectorImageType* in)
+  : ocif(OutputClampImageFilter::New())
+  , out(ocif->GetOutput())
   {
     assert(in);
 
     ocif->SetInput(in);
   }
 
-  /** Input-image clamp filter. */
-  itk::ProcessObject::Pointer icif;
-
   /** Output-image clamp filter. */
   typename OutputClampImageFilter::Pointer ocif;
 
@@ -119,7 +107,6 @@ struct OTBApplicationEngine_EXPORT_TEMPLATE CastImage<T, T>
     assert(in);
   }
 
-  itk::ProcessObject::Pointer icif;
   itk::ProcessObject::Pointer ocif;
   T*                          out;
 };
@@ -139,7 +126,6 @@ struct OTBApplicationEngine_EXPORT_TEMPLATE CastImage<DoubleVectorImageType, Dou
     assert(in);
   }
 
-  itk::ProcessObject::Pointer icif;
   itk::ProcessObject::Pointer ocif;
   DoubleVectorImageType*      out;
 };
