@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -173,7 +173,7 @@ public:
 
   void FromString(const std::string& value) override
   {
-    SetValue(value);
+    SetSelectedNames({value});
   }
 
   std::vector<std::string> ToStringList() const override
