@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -275,7 +275,7 @@ int Read(const std::string& filename, Application::Pointer this_)
       std::stringstream(value) >> doubleValue;
       this_->SetParameterDouble(key, doubleValue);
     }
-    else if (type == ParameterType_StringList || type == ParameterType_ListView)
+    else if (type == ParameterType_StringList || type == ParameterType_ListView || type == ParameterType_Field)
     {
       this_->SetParameterStringList(key, values);
     }
