@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -40,12 +40,12 @@ public:
 
   bool notify(QObject* object, QEvent* event) override;
 
-signals:
+Q_SIGNALS:
 
   void UnhandledException(QString message);
 };
 
 } // end of namespace Wrapper
-} // end of namepsace otb
+} // end of namespace otb
 
 #endif
