@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -64,7 +64,7 @@ public:
   /** Write to a buffer */
   void Write(std::string const& content, double timestamp) override;
 
-signals:
+Q_SIGNALS:
   void NewContentLog(QString);
 
 protected:
