@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -46,7 +46,7 @@ public:
   const QLineEdit* GetInput() const;
   QLineEdit*       GetInput();
 
-protected slots:
+protected Q_SLOTS:
   void SetFileName(const QString& value);
   void SelectFile();
 
