@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -45,7 +45,7 @@ public:
   QtWidgetIntParameter(IntParameter*, QtWidgetModel*, QWidget*);
   ~QtWidgetIntParameter() override;
 
-private slots:
+private Q_SLOTS:
   void OnCleared();
   void OnValueChanged(int);
   void OnEditingFinished();
