@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -134,7 +134,7 @@ void QtMainWindow::on_executeButton_clicked()
       gui->Disable();
       ui->statusBar->showMessage(tr("Running..."));
       ui->executeButton->setText(tr("Cancel"));
-      emit ExecuteAndWriteOutput();
+      Q_EMIT ExecuteAndWriteOutput();
     }
   }
 }
