@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -71,7 +71,7 @@ void QtWidgetParameterList::DoCreateWidget()
 
   //
   // Connections (Update UserValue flag).
-  QObject::connect(widget, &ListEditWidget::ValueChanged, this, [=]() { emit ParameterChanged(GetParam()->GetKey()); });
+  QObject::connect(widget, &ListEditWidget::ValueChanged, this, [=]() { Q_EMIT ParameterChanged(GetParam()->GetKey()); });
 
   // Connections (Update app parameters).
   QObject::connect(widget, &ListEditWidget::Updated, this, &QtWidgetParameterList::NotifyUpdate);
