@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 1999-2011 Insight Software Consortium
- * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+ * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
  *
  * This file is part of Orfeo Toolbox
  *
@@ -29,9 +29,9 @@ class PyGILStateEnsure
 {
 public:
   PyGILStateEnsure()
-    {
-      m_GIL = PyGILState_Ensure();
-    }
+    :
+    m_GIL(PyGILState_Ensure())
+  {}
   ~PyGILStateEnsure()
     {
       PyGILState_Release(m_GIL);
