@@ -2,7 +2,7 @@
 #
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
+# Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
 #
 # This file is part of Orfeo Toolbox
 #
@@ -118,7 +118,6 @@ excludedfiles = set([
     './CMake/FindGLEW.cmake',
     './CMake/FindKWStyle.cmake',
     './CMake/FindLibSVM.cmake',
-    './CMake/FindOpenThreads.cmake',
     './CMake/Findcppcheck.cmake',
     './CMake/Findcppcheck.cpp',
     './CMake/GenerateExportHeaderCustom.cmake',
@@ -130,9 +129,12 @@ excludedfiles = set([
     './CMake/exportheader.cmake.in',
     './CMake/pre-commit',
     './CMake/qt.conf.in',
+    './Docker/Dockerfile',
+    './Docker/system-dependencies.txt',
     './Documentation/Cookbook/Art/residual_registration-figure.tex',
     './Documentation/Cookbook/rst/Makefile.in',
     './Documentation/Cookbook/rst/conf.py.in',
+    './Documentation/Cookbook/Scripts/gdal-config',
     './Modules/Visualization/Ice/README',
     './Modules/Wrappers/SWIG/src/numpy.i',
     './Packaging/Files/Monteverdi.icns',
@@ -140,6 +142,7 @@ excludedfiles = set([
     './Packaging/Files/qt.conf',
     './Packaging/Files/template.app/Contents/Info.plist',
     './Packaging/LICENSE',
+    './Packaging/patchelf_remove_warning.diff',
     './Packaging/howto_update_makeself',
     './Packaging/otb_update_makeself',
     './SuperBuild/LICENSE',
